@@ -58,6 +58,9 @@ LAVA_MULTINODE_SYSTEM_TIMEOUT = 90
 # Default Action timeout
 ACTION_TIMEOUT = 30
 
+# Max cleanup timeout
+CLEANUP_TIMEOUT = 5 * 60
+
 # Android tmp directory
 ANDROID_TMP_DIR = "/data/local/tmp"
 
