@@ -144,7 +144,13 @@ def timeout():
 
 def action():
     return {
-        Optional("namespace"): All(str, NotIn(["common"], msg="'common' is reserved")),
+        Optional("namespace"): All(
+            str,
+            NotIn(
+                ["common", "docker-test-shell"],
+                msg="'common' and 'docker-test-shell' are reserved namespace names",
+            ),
+        ),
         Optional("connection-namespace"): str,
         Optional("protocols"): object,
         Optional("role"): [str],
@@ -167,9 +173,16 @@ def notify():
 
     return {
         Required("criteria"): Any(
+            {
+                Required("status"): "all",
+            },
             {
                 Required("status"): Any(
-                    "finished", "running", "complete", "canceled", "incomplete"
+                    "finished",
+                    "running",
+                    "complete",
+                    "canceled",
+                    "incomplete",
                 ),
                 Optional("dependency_query"): str,
             },
@@ -204,9 +217,8 @@ def notify():
 
 def extra_checks(data):
     check_job_timeouts(data)
-    check_multinode_or_device_type(data)
-    check_multinode_or_environment(data)
     check_multinode_roles(data)
+    check_multinode_extras(data)
     check_namespace(data)
 
 
@@ -245,22 +257,16 @@ def check_job_timeouts(data):
         _check_timeout("Action", ["actions", str(index)], t)
 
 
-def check_multinode_or_device_type(data):
-    device_type = data.get("device_type")
+def check_multinode_extras(data):
     multinode = data.get("protocols", {}).get("lava-multinode")
 
-    if device_type and multinode:
-        raise Invalid('"device_type" should not be used with multinode')
-    if not device_type and not multinode:
-        raise Invalid('"device_type" or multinode should be defined')
-
-
-def check_multinode_or_environment(data):
-    environment = data.get("environment")
-    multinode = data.get("protocols", {}).get("lava-multinode")
-
-    if environment and multinode:
-        raise Invalid('"environment" should not be used with multinode')
+    extras = ("device_type", "environment", "context", "tags")
+    for extra in extras:
+        extra_value = data.get(extra)
+        if extra_value and multinode:
+            raise Invalid(f'"{extra}" should not be used with multinode')
+        if extra == "device_type" and not extra_value and not multinode:
+            raise Invalid(f'"{extra}" or multinode should be defined')
 
 
 def check_multinode_roles(data):
@@ -375,9 +381,11 @@ def job(extra_context_variables=[]):
     )
 
 
+docker_image_format_pattern = (
+    "^[a-z0-9]+[a-z0-9._/:-]*[a-z0-9]+(:[a-zA-Z0-9_]+[a-zA-Z0-9._-]*)?$"
+)
 docker_image_format = Match(
-    "^[a-z0-9]+[a-z0-9._/:-]*[a-z0-9]+(:[a-zA-Z0-9_]+[a-zA-Z0-9._-]*)?$",
-    msg="Invalid docker image name",
+    docker_image_format_pattern, msg="Invalid docker image name"
 )
 
 
