@@ -46,3 +46,16 @@ def ldap_available(request):
     )
     login_message_ldap = getattr(settings, "LOGIN_MESSAGE_LDAP", "")
     return {"ldap_available": ldap_enabled, "login_message_ldap": login_message_ldap}
+
+
+def oidc_context(request):
+    return {
+        "oidc_enabled": settings.OIDC_ENABLED,
+        "oidc_account_name": settings.LAVA_OIDC_ACCOUNT_NAME,
+    }
+
+
+def socialaccount(request):
+    return {
+        "socialaccount_enabled": settings.AUTH_SOCIALACCOUNT is not None,
+    }
