@@ -31,6 +31,7 @@ from django.contrib.auth.models import User
 from django.core.mail import mail_admins
 from django.core.management.base import BaseCommand, CommandError
 from django.db import transaction
+from django.db.models import Q
 from django.utils import timezone
 
 from lava_common.compat import yaml_safe_load
@@ -41,7 +42,8 @@ from lava_server.compat import get_sub_parser_class
 
 def _create_output_size(base, size):
     (base / "output.yaml.size").write_text(str(size), encoding="utf-8")
-    chown(str(base / "output.yaml.size"), "lavaserver", "lavaserver")
+    with contextlib.suppress(PermissionError):
+        chown(str(base / "output.yaml.size"), "lavaserver", "lavaserver")
 
 
 class Command(BaseCommand):
@@ -122,19 +124,6 @@ class Command(BaseCommand):
             "form: 1h (one hour) or 2d (two days). "
             "By default, all jobs will be removed.",
         )
-        rm.add_argument(
-            "--state",
-            default=None,
-            choices=[
-                "SUBMITTED",
-                "SCHEDULING",
-                "SCHEDULED",
-                "RUNNING",
-                "CANCELING",
-                "FINISHED",
-            ],
-            help="Filter by job state",
-        )
         rm.add_argument(
             "--submitter", default=None, type=str, help="Filter jobs by submitter"
         )
@@ -214,7 +203,7 @@ class Command(BaseCommand):
         )
 
     def handle(self, *_, **options):
-        """ forward to the right sub-handler """
+        """forward to the right sub-handler"""
         if options["sub_command"] == "list":
             self.handle_list(
                 options["lxc"],
@@ -227,7 +216,6 @@ class Command(BaseCommand):
             self.handle_rm(
                 options["older_than"],
                 options["submitter"],
-                options["state"],
                 options["dry_run"],
                 options["slow"],
             )
@@ -303,14 +291,16 @@ class Command(BaseCommand):
                     f"* {job.submit_time} - {job.id}@{job.submitter} - {job.description}"
                 )
 
-    def handle_rm(self, older_than, submitter, state, simulate, slow):
-        if not older_than and not submitter and not state:
+    def handle_rm(self, older_than, submitter, simulate, slow):
+        if not older_than and not submitter:
             raise CommandError("You should specify at least one filtering option")
 
         if simulate:
             transaction.set_autocommit(False)
 
         jobs = TestJob.objects.all().order_by("id")
+        jobs = jobs.filter(state=TestJob.STATE_FINISHED)
+
         if older_than is not None:
             pattern = re.compile(r"^(?P<time>\d+)(?P<unit>(h|d))$")
             match = pattern.match(older_than)
@@ -321,7 +311,10 @@ class Command(BaseCommand):
                 delta = datetime.timedelta(days=int(match.groupdict()["time"]))
             else:
                 delta = datetime.timedelta(hours=int(match.groupdict()["time"]))
-            jobs = jobs.filter(end_time__lt=(timezone.now() - delta))
+            jobs = jobs.filter(
+                Q(end_time__lt=(timezone.now() - delta))
+                | Q(end_time__isnull=True, submit_time__lt=(timezone.now() - delta))
+            )
 
         if submitter is not None:
             try:
@@ -330,11 +323,9 @@ class Command(BaseCommand):
                 raise CommandError("Unable to find submitter '%s'" % submitter)
             jobs = jobs.filter(submitter=user)
 
-        if state is not None:
-            jobs = jobs.filter(state=self.job_state[state])
-
         self.stdout.write("Removing %d jobs:" % jobs.count())
 
+        media_root = pathlib.Path(settings.MEDIA_ROOT)
         while True:
             count = 0
             for job in jobs[0:100]:
@@ -345,6 +336,14 @@ class Command(BaseCommand):
                 try:
                     if not simulate:
                         rmtree(job.output_dir)
+                        # delete parents directories (if empty)
+                        with contextlib.suppress(OSError, ValueError):
+                            for parent in pathlib.Path(job.output_dir).parents:
+                                parent.relative_to(media_root)
+                                if parent == media_root:
+                                    break
+                                parent.rmdir()
+                                self.stdout.write("  -> rmdir %s" % (parent))
                 except OSError as exc:
                     self.stderr.write(
                         "  -> Unable to remove the directory: %s" % str(exc)
@@ -481,7 +480,8 @@ class Command(BaseCommand):
                     # Compresse the logs
                     with lzma.open(str(base / "output.yaml.xz"), "wb") as f_out:
                         f_out.write(data)
-                    chown(str(base / "output.yaml.xz"), "lavaserver", "lavaserver")
+                    with contextlib.suppress(PermissionError):
+                        chown(str(base / "output.yaml.xz"), "lavaserver", "lavaserver")
                     # Remove the original file
                     (base / "output.yaml").unlink()
             except OSError as exc:
