@@ -94,6 +94,8 @@ MIDDLEWARE = [
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
 ]
 
+LAVA_REQUIRE_LOGIN_MIDDLEWARE = "lava_server.security.LavaRequireLoginMiddleware"
+
 ROOT_URLCONF = "lava_server.urls"
 
 TEMPLATES = [
@@ -112,6 +114,8 @@ TEMPLATES = [
                 # LAVA context processors
                 "lava_server.context_processors.lava",
                 "lava_server.context_processors.ldap_available",
+                "lava_server.context_processors.oidc_context",
+                "lava_server.context_processors.socialaccount",
             ]
         },
     }
@@ -226,6 +230,11 @@ AUTH_LDAP_GROUP_TYPE = None
 # Social accounts support
 AUTH_SOCIALACCOUNT = None
 
+# OIDC support
+AUTH_OIDC = None
+OIDC_ENABLED = False
+LAVA_OIDC_ACCOUNT_NAME = "Open ID Connect account"
+
 # Gitlab support
 AUTH_GITLAB_URL = None
 AUTH_GITLAB_SCOPE = ["read_user"]
@@ -332,11 +341,13 @@ def update(values):
     AUTH_LDAP_USER_SEARCH = values.get("AUTH_LDAP_USER_SEARCH")
     AUTH_DEBIAN_SSO = values.get("AUTH_DEBIAN_SSO")
     AUTH_SOCIALACCOUNT = values.get("AUTH_SOCIALACCOUNT")
+    AUTH_OIDC = values.get("AUTH_OIDC")
     AUTH_GITLAB_URL = values.get("AUTH_GITLAB_URL")
     AUTH_GITLAB_SCOPE = values.get("AUTH_GITLAB_SCOPE")
     AUTHENTICATION_BACKENDS = values.get("AUTHENTICATION_BACKENDS")
     DISALLOWED_USER_AGENTS = values.get("DISALLOWED_USER_AGENTS")
     DJANGO_LOGFILE = values.get("DJANGO_LOGFILE")
+    EVENT_NOTIFICATION = values.get("EVENT_NOTIFICATION")
     INSTALLED_APPS = values.get("INSTALLED_APPS")
     INTERNAL_IPS = values.get("INTERNAL_IPS")
     LOGGING = values.get("LOGGING")
@@ -346,6 +357,7 @@ def update(values):
     SENTRY_DSN = values.get("SENTRY_DSN")
     STATEMENT_TIMEOUT = values.get("STATEMENT_TIMEOUT")
     USE_DEBUG_TOOLBAR = values.get("USE_DEBUG_TOOLBAR")
+    REQUIRE_LOGIN = values.get("REQUIRE_LOGIN")
 
     # Fix mount point
     # Remove the leading slash and keep only one trailing slash
@@ -364,6 +376,9 @@ def update(values):
     ADMINS = [tuple(v) for v in ADMINS]
     MANAGERS = [tuple(v) for v in MANAGERS]
 
+    # EVENT_NOTIFICATION is a boolean
+    EVENT_NOTIFICATION = bool(EVENT_NOTIFICATION)
+
     # Social accounts authentication config
     if AUTH_SOCIALACCOUNT or AUTH_GITLAB_URL:
         auth_socialaccount = {}
@@ -398,6 +413,60 @@ def update(values):
             )
             SOCIALACCOUNT_PROVIDERS = auth_socialaccount
 
+    # OIDC authentication
+    if AUTH_OIDC is not None:
+        try:
+            LAVA_OIDC_ACCOUNT_NAME = AUTH_OIDC.pop("LAVA_OIDC_ACCOUNT_NAME")
+        except KeyError:
+            ...
+
+        oidc_keys = {
+            "OIDC_OP_AUTHORIZATION_ENDPOINT",
+            "OIDC_OP_TOKEN_ENDPOINT",
+            "OIDC_OP_USER_ENDPOINT",
+            "OIDC_RP_CLIENT_ID",
+            "OIDC_RP_CLIENT_SECRET",
+            "OIDC_VERIFY_JWT",
+            "OIDC_VERIFY_KID",
+            "OIDC_USE_NONCE",
+            "OIDC_VERIFY_SSL",
+            "OIDC_TIMEOUT",
+            "OIDC_PROXY",
+            "OIDC_EXEMPT_URLS",
+            "OIDC_CREATE_USER",
+            "OIDC_STATE_SIZE",
+            "OIDC_NONCE_SIZE",
+            "OIDC_MAX_STATES",
+            "OIDC_REDIRECT_FIELD_NAME",
+            "OIDC_CALLBACK_CLASS",
+            "OIDC_AUTHENTICATE_CLASS",
+            "OIDC_RP_SCOPES",
+            "OIDC_STORE_ACCESS_TOKEN",
+            "OIDC_STORE_ID_TOKEN",
+            "OIDC_AUTH_REQUEST_EXTRA_PARAMS",
+            "OIDC_RP_SIGN_ALGO",
+            "OIDC_RP_IDP_SIGN_KEY",
+            "OIDC_OP_LOGOUT_URL_METHOD",
+            "OIDC_AUTHENTICATION_CALLBACK_URL",
+            "OIDC_ALLOW_UNSECURED_JWT",
+            "OIDC_TOKEN_USE_BASIC_AUTH",
+        }
+
+        if not oidc_keys.issuperset(AUTH_OIDC.keys()):
+            raise ImproperlyConfigured(
+                "Unknown OIDC configuration keys: ",
+                set(AUTH_OIDC.keys()).difference(oidc_keys),
+            )
+
+        INSTALLED_APPS.append("mozilla_django_oidc")
+        AUTHENTICATION_BACKENDS.append(
+            "lava_server.oidc_sso.OIDCAuthenticationBackendUsernameFromEmail"
+        )
+        MIDDLEWARE.append("mozilla_django_oidc.middleware.SessionRefresh")
+
+        OIDC_ENABLED = True
+        locals().update(AUTH_OIDC)
+
     # LDAP authentication config
     if AUTH_LDAP_SERVER_URI:
         INSTALLED_APPS.append("ldap")
@@ -448,6 +517,9 @@ def update(values):
         MIDDLEWARE = ["debug_toolbar.middleware.DebugToolbarMiddleware"] + MIDDLEWARE
         INTERNAL_IPS.extend(["127.0.0.1", "::1"])
 
+    if REQUIRE_LOGIN and LAVA_REQUIRE_LOGIN_MIDDLEWARE not in MIDDLEWARE:
+        MIDDLEWARE.append(LAVA_REQUIRE_LOGIN_MIDDLEWARE)
+
     # List of compiled regular expression objects representing User-Agent strings
     # that are not allowed to visit any page, systemwide. Use this for bad
     # robots/crawlers
@@ -455,51 +527,57 @@ def update(values):
         re.compile(r"%s" % reg, re.IGNORECASE) for reg in DISALLOWED_USER_AGENTS
     ]
 
-    LOGGING = {
-        "version": 1,
-        "disable_existing_loggers": False,
-        "filters": {
-            "require_debug_false": {"()": "django.utils.log.RequireDebugFalse"}
-        },
-        "formatters": {
-            "lava": {"format": "%(levelname)s %(asctime)s %(module)s %(message)s"}
-        },
-        "handlers": {
-            "console": {
-                "level": "DEBUG",
-                "class": "logging.StreamHandler",
-                "formatter": "lava",
+    if LOGGING is None:
+        LOGGING = {
+            "version": 1,
+            "disable_existing_loggers": False,
+            "filters": {
+                "require_debug_false": {"()": "django.utils.log.RequireDebugFalse"}
             },
-            "logfile": {
-                "class": "logging.handlers.WatchedFileHandler",
-                "filename": DJANGO_LOGFILE,
-                "formatter": "lava",
+            "formatters": {
+                "lava": {"format": "%(levelname)s %(asctime)s %(module)s %(message)s"}
             },
-        },
-        "loggers": {
-            "django": {
-                "handlers": ["logfile"],
-                # DEBUG outputs all SQL statements
-                "level": "ERROR",
-                "propagate": True,
+            "handlers": {
+                "console": {
+                    "level": "DEBUG",
+                    "class": "logging.StreamHandler",
+                    "formatter": "lava",
+                },
+                "logfile": {
+                    "class": "logging.handlers.WatchedFileHandler",
+                    "filename": DJANGO_LOGFILE,
+                    "formatter": "lava",
+                },
             },
-            "django_auth_ldap": {
-                "handlers": ["logfile"],
-                "level": "INFO",
-                "propagate": True,
+            "loggers": {
+                "django": {
+                    "handlers": ["logfile"],
+                    # DEBUG outputs all SQL statements
+                    "level": "ERROR",
+                    "propagate": True,
+                },
+                "django_auth_ldap": {
+                    "handlers": ["logfile"],
+                    "level": "INFO",
+                    "propagate": True,
+                },
+                "lava_results_app": {
+                    "handlers": ["logfile"],
+                    "level": "INFO",
+                    "propagate": True,
+                },
+                "lava_scheduler_app": {
+                    "handlers": ["logfile"],
+                    "level": "INFO",
+                    "propagate": True,
+                },
+                "mozilla_django_oidc": {
+                    "handlers": ["logfile"],
+                    "level": "DEBUG",
+                    "propagate": True,
+                },
             },
-            "lava_results_app": {
-                "handlers": ["logfile"],
-                "level": "INFO",
-                "propagate": True,
-            },
-            "lava_scheduler_app": {
-                "handlers": ["logfile"],
-                "level": "INFO",
-                "propagate": True,
-            },
-        },
-    }
+        }
 
     if SENTRY_DSN:
         import sentry_sdk
