@@ -83,12 +83,12 @@ def check_job(data, options, prefix=""):
 
 def handle(options, files, glob, check):
     failed = 0
-    for fileobj in files:
+    for fileobj in sorted(files):
         if fileobj.is_dir() and options.recursive:
             files_iter = fileobj.rglob(glob)
         else:
             files_iter = [fileobj]
-        for f in files_iter:
+        for f in sorted(files_iter):
             if not f.exists():
                 print("* %s [does not exists]" % str(f))
                 failed += 1
@@ -175,7 +175,10 @@ def main():
         if options.render:
             # Add default value for --path
             if options.path is None:
-                options.path = ["/etc/lava-server/dispatcher-config/device-types"]
+                options.path = [
+                    "/etc/lava-server/dispatcher-config/device-types",
+                    "/usr/share/lava-server/device-types",
+                ]
             # create the jinja2 environment once as this is a slow operation
             options.env = jinja2.Environment(  # nosec - used to render yaml
                 autoescape=False, loader=jinja2.FileSystemLoader(options.path)
