@@ -62,6 +62,16 @@ def run(cmd_list, failure_msg, stdin=None):
     return ret
 
 
+def is_pg_available():
+    # is the database ready?
+    try:
+        subprocess.check_call(["pg_isready"])
+        return True
+    except subprocess.CalledProcessError:
+        print("Skipping database creation as PostgreSQL is not running")
+        return False
+
+
 def create_database(config):
     db = config["DATABASES"]["default"]["NAME"]
     password = config["DATABASES"]["default"]["PASSWORD"]
@@ -70,13 +80,6 @@ def create_database(config):
     devel_password = "devel"
     devel_user = "devel"
 
-    # is the database ready?
-    try:
-        subprocess.check_call(["pg_isready"])
-    except subprocess.CalledProcessError:
-        print("Skipping database creation as PostgreSQL is not running")
-        return
-
     script = f"""
 DO $$
 BEGIN
@@ -197,9 +200,6 @@ def fixup():
     (LAVA_LOGS / "django.log").write_text("", encoding="utf-8")
     print(f"  - {LAVA_LOGS}/*")
     for logfile in LAVA_LOGS.glob("*"):
-        if "lava-scheduler.log" in str(logfile):
-            # skip changes to old logs.
-            continue
         shutil.chown(logfile, LAVA_SYS_USER, "adm")
         # allow users in the adm group to run lava-server commands
         logfile.chmod(0o0664)
@@ -252,7 +252,7 @@ def main():
         if options.config is None:
             options.config = True
         if options.db is None:
-            options.db = True
+            options.db = is_pg_available()
         if options.fixup is None:
             options.fixup = True
 
@@ -281,7 +281,7 @@ SECRET_KEY: "{get_random_secret_key()}"
         else:
             print("* generate SECRET_KEY [SKIP]")
 
-        if not config.get("DATABASES"):
+        if options.db and not config.get("DATABASES"):
             print("* generate DATABASES")
             GEN_DATABASE.write_text(
                 f"""# This file was generated by /usr/share/lava-server/postinst.py
