@@ -41,7 +41,7 @@ def test_sender(mocker):
         f"{i:04}".encode("utf-8") for i in range(0, 1001)
     ] + [b""]
 
-    sender(conn, "http://localhost", "my-token")
+    sender(conn, "http://localhost", "my-token", 1)
     assert len(conn.poll.mock_calls) == 2000
     assert len(conn.recv_bytes.mock_calls) == 1002
 
@@ -73,7 +73,7 @@ def test_sender_exceptions(mocker):
     conn.recv_bytes = mocker.MagicMock()
     conn.recv_bytes.side_effect = [b"hello world", b""]
 
-    sender(conn, "http://localhost", "my-token")
+    sender(conn, "http://localhost", "my-token", 1)
     assert len(post.mock_calls) == 3
     for c in post.mock_calls:
         assert c[1] == ("http://localhost",)
@@ -84,7 +84,7 @@ def test_http_handler(mocker):
     Process = mocker.Mock()
     mocker.patch("multiprocessing.Process", return_value=Process)
     mocker.patch("multiprocessing.Pipe", return_value=(mocker.Mock(), mocker.Mock()))
-    handler = HTTPHandler("http://localhost/", "token")
+    handler = HTTPHandler("http://localhost/", "token", 1)
 
     assert len(Process.start.mock_calls) == 1
     assert len(Process.start.mock_calls) == 1
@@ -123,7 +123,7 @@ def test_yaml_logger(mocker):
 
     logger = YAMLLogger("lava")
     assert logger.handler is None
-    logger.addHTTPHandler("http://localhost/", "my-token")
+    logger.addHTTPHandler("http://localhost/", "my-token", 1)
     assert isinstance(logger.handler, HTTPHandler) is True
 
     def check(logger, lvl, lvlno, msg=None, mock_calls=1):
