@@ -1073,13 +1073,18 @@ def test_device_types_show(setup):
     dt = DeviceType.objects.create(name="qemu")
     data = server("admin", "admin").scheduler.device_types.show("qemu")
 
+    from lava_server.files import File
+
     assert data == {  # nosec
         "name": "qemu",
         "description": None,
         "display": True,
         "health_disabled": False,
+        "health_denominator": "hours",
+        "health_frequency": 24,
         "aliases": [],
         "devices": [],
+        "default_template": False,
     }
 
     # 3. More details
@@ -1091,8 +1096,11 @@ def test_device_types_show(setup):
         "description": None,
         "display": True,
         "health_disabled": False,
+        "health_denominator": "hours",
+        "health_frequency": 24,
         "aliases": [],
         "devices": ["device01"],
+        "default_template": False,
     }
 
 
@@ -1760,6 +1768,9 @@ def test_workers_show(setup):
             "last_ping",
             "job_limit",
             "version",
+            "default_config",
+            "default_env",
+            "default_env_dut",
         ]
     )
     assert data["hostname"] == "example.com"  # nosec
